;------------------------------------------------------------
;------------------------------------------------------------
;------------------------------------------------------------
;+
; NAME: depth2mask
;
; PURPOSE: permet de passer d''un tableau 2d de profondeur seuil au
; tableau 3d de mask avec des 1 ds les niveaux au dessus de la
; profondeur seuil et des 0 en dessous.
;
; CATEGORY: SANS BOUCLE
;
; CALLING SEQUENCE: res=depth2mask(depht2d)
;
; INPUTS: depht2d tableau 2d de profondeur seuil (ou une structure repondant
; aux criteres de litchamp)
;
; KEYWORD PARAMETERS:
;
;      /UPPER: (active par defaut) on selectionne le niveau
;      directement au dessus de la profondeur
;
;      /LOWER: on selectionne le niveau directement au dessous de la
;      profondeur 
;
;      /CLOSER: on selectionne le niveau le plus proche de la
;      profondeur 
;
; OUTPUTS: un tableau 3d contenant le mask associe au tableau 2d de
; profondeurs seuil
;
; COMMON BLOCKS:
;	common.pro
;
; SIDE EFFECTS:
;
; RESTRICTIONS:
;
; EXAMPLE:
;
; MODIFICATION HISTORY: Sebastien Masson (smasson@lodyc.jussieu.fr)
;                       17/6/1999
;-
;------------------------------------------------------------
;------------------------------------------------------------
;------------------------------------------------------------
FUNCTION depth2mask, tab, _extra = ex
;------------------------------------------------------------
;
  compile_opt idl2, strictarrsubs
;
   tempsun = systime(1)         ; pour key_performance
@common
;------------------------------------------------------------
; on transforme le tableau 2d de profondeur en tableau 2d de niveaux
; correspondant aux profondeurs
;------------------------------------------------------------
   niveaux = depth2level(tab, _extra = ex)
   IF niveaux[0] EQ -1 THEN return,  -1
;------------------------------------------------------------
; on transforme le tableau 2d de niveaux en tableau 3d de mask
;------------------------------------------------------------
   mask = level2mask(niveaux)
;------------------------------------------------------------
   if keyword_set(key_performance) NE 0 THEN print, 'temps depth2mask', systime(1)-tempsun 
   return, mask
end
